netapp_ontap.models.node_ha_takeover_failure API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_ha_takeover_failure`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeHaTakeoverFailureSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeHaTakeoverFailure object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `code GET POST PATCH`

    Message code

    Example: 852130

  `message GET POST PATCH`

    Detailed message based on the state.

    Example: Failed to initiate takeover. Run the "storage failover show-takeover" command for more information.